import { DLine } from './DLine';
import { DPolygon } from './DPolygon';
export declare const PSEUDO_MERCATOR = "EPSG:3857";
export declare const WORLD_GEODETIC_SYSTEM = "EPSG:4326";
export declare const EARTH_RADIUS_IN_METERS = 6371008.8;
export declare type DCoord = [number, number] | [number, number, number];
export interface LatLng {
    lat: number;
    lng: number;
}
export declare const HALF_PI_IN_DEGREE = 90;
export declare const PI_IN_DEGREE = 180;
export declare const DOUBLE_PI_IN_DEGREE = 360;
export declare const PI_TO_DEGREE: number;
export declare const DEGREE_TO_PI: number;
declare type SetterFunction = (t: DPoint) => number;
export declare class DPoint {
    x: number;
    y: number;
    z?: number;
    properties: {
        [key: string]: any;
    };
    /**
     *
     * @param x - lng, meters to East, radians to East or width
     * @param y - lat, meters to North, radians to North or height
     * @param z - height
     */
    constructor(x?: number, y?: number, z?: number);
    static Zero(): DPoint;
    static parse(c: LatLng | number[] | DCoord): DPoint;
    static isPoint(p: unknown): boolean;
    static parseFromWKT(wkt: string): DPoint;
    static Random(): DPoint;
    getTileFromCoords(zoom?: number): DPoint;
    getCoordsFromTile(zoom?: number): DPoint;
    toCoords(): DCoord;
    /**
     * Find line between two points.
     * @param p
     */
    findLine(p: DPoint): DLine;
    findInnerAngle(p1: DPoint, p3: DPoint): number;
    transform(from?: string, to?: string): DPoint;
    toString(): string;
    getValue(): [number, number];
    height(z: number): DPoint;
    toWKT(): string;
    distance(p: DPoint): number;
    setX(x: number | SetterFunction): DPoint;
    setY(y: number | SetterFunction): DPoint;
    clone(): DPoint;
    gt(p: DPoint): boolean;
    lt(p: DPoint): boolean;
    gtOrEqual(p: DPoint): boolean;
    ltOrEqual(p: DPoint): boolean;
    /**
     * @deprecated
     * @param a
     */
    rotate(a: number): DPoint;
    /**
     * @deprecated
     * @param x
     * @param y
     */
    move(x?: number | DPoint, y?: number): DPoint;
    /**
     * @deprecated
     */
    round(): DPoint;
    /**
     * @deprecated
     */
    ceil(): DPoint;
    /**
     * @deprecated
     */
    floor(): DPoint;
    /**
     * @deprecated
     * @param n
     */
    toFixed(n?: number): DPoint;
    /**
     * @deprecated
     */
    abs(): DPoint;
    /**
     * @deprecated
     * @param x
     * @param y
     */
    scale(x?: number | DPoint, y?: number): DPoint;
    /**
     * @deprecated
     * @param x
     * @param y
     */
    divide(x?: number | DPoint, y?: number): DPoint;
    rotateCurrent(a: number): DPoint;
    moveCurrent(x?: number | DPoint, y?: number): DPoint;
    asRadians(): DPoint;
    asDegrees(): DPoint;
    roundCurrent(): DPoint;
    ceilCurrent(): DPoint;
    floorCurrent(): DPoint;
    toFixedCurrent(n?: number): DPoint;
    absCurrent(): DPoint;
    scaleCurrent(x?: number | DPoint, y?: number): DPoint;
    divideCurrent(x?: number | DPoint, y?: number): DPoint;
    equal(p: DPoint): boolean;
    like(p: DPoint, d?: number): boolean;
    get w(): number;
    set w(x: number);
    get h(): number;
    set h(y: number);
    get area(): number;
    get hip(): number;
    get min(): number;
    get max(): number;
    get hipPoint(): DPoint;
    get xPoint(): DPoint;
    get yPoint(): DPoint;
    get wPoint(): DPoint;
    get hPoint(): DPoint;
    simple(xKey?: string, yKey?: string): {
        [key: string]: number;
    };
    setIfLessThan(p: DPoint): DPoint;
    minus(): DPoint;
    orthodromicPath(point: DPoint, pointsCount?: number): DPolygon;
    private degrees2meters;
    private meters2degrees;
}
export {};
